---
title: <span class="badge object-type-scalar"></span> Real
---
# <span class="badge object-type-scalar"></span> Real

Currency: Real (R$)

## Definition

```python
# Currency: Real (R$)
Real: typing.Literal["currencyBRL"] = "currencyBRL"
```
